@@ -1001,7 +1001,7 @@ static void _on_map_menuitem (GtkWidget *pMenuItem, gpointer data)
 	if (data) gtk_widget_set_tooltip_text (pMenuItem, (const gchar*)data);
 }
 
-static void _weak_free_helper (gpointer ptr, GObject*)
+static void _weak_free_helper (gpointer ptr, G_GNUC_UNUSED GObject* pObj)
 {
 	g_free (ptr);
 }
